# Various tests taken/based from
# https://github.com/cta-observatory/cta-lstchain/blob/master/lstchain/scripts/tests/test_lstchain_scripts.py

import pytest
import subprocess
import pkg_resources
import os
import shutil
from pathlib import Path
from os.path import dirname, realpath, join
from eossr.scripts import eossr_upload_repository

ROOT_DIR = dirname(realpath("codemeta.json"))


def find_entry_points(package_name):
    """from: https://stackoverflow.com/a/47383763/3838691"""
    entrypoints = [
        ep.name
        for ep in pkg_resources.iter_entry_points("console_scripts")
        if ep.module_name.startswith(package_name)
    ]
    return entrypoints


ALL_SCRIPTS = find_entry_points("eossr")


def run_script(*args):
    result = subprocess.run(args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, encoding='utf-8')

    if result.returncode != 0:
        raise ValueError(
            f"Running {args[0]} failed with return code {result.returncode}"
            f", output: \n {result.stdout}"
        )


def test_codemeta2zenodo():
    existing_zenodo_file = Path(ROOT_DIR).joinpath('.zenodo.json')
    if existing_zenodo_file.exists():
        existing_zenodo_file.unlink()

    run_script("eossr-codemeta2zenodo", "-i", join(ROOT_DIR, "codemeta.json"))
    existing_zenodo_file.unlink()


def test_parse_last_release_git_bash():
    run_script("which", "gitlab_prepare_upload_zenodo.sh")


@pytest.mark.parametrize("script", ALL_SCRIPTS)
def test_help_all_scripts(script):
    """Test for all scripts if at least the help works"""
    run_script(script, "--help")


def test_eossr_upload_repository(tmpdir):
    path_test_filename = Path(tmpdir).joinpath('test.txt')
    Path(path_test_filename).write_text('Hello World')
    shutil.copy(Path(ROOT_DIR).joinpath('codemeta.json'), tmpdir)
    record_id = eossr_upload_repository.upload(zenodo_token=os.getenv('SANDBOX_ZENODO_TOKEN'),
                                               sandbox_flag=True,
                                               upload_directory=tmpdir,
                                               force_new_record=True
                                               )

    Path(path_test_filename).write_text('Hello World 2')
    eossr_upload_repository.upload(zenodo_token=os.getenv('SANDBOX_ZENODO_TOKEN'),
                                   sandbox_flag=True,
                                   upload_directory=tmpdir,
                                   record_id=record_id
                                   )

