from pathlib import Path
import os
import tempfile
from zipfile import ZipFile
from eossr.utils import get_codemeta_from_zipurl, ZipUrl


_testurl = 'https://zenodo.org/record/5524913/files/eossr-v0.2.zip'


def test_ZipUrl():
    zipurl = ZipUrl(_testurl)
    codemeta_paths = zipurl.find_files('codemeta.json')

    assert 'eossr-v0.2/codemeta.json' in codemeta_paths
    assert 'eossr-v0.2/eossr/metadata/schema/codemeta.json' in codemeta_paths
    zipurl.extract_file('eossr-v0.2/codemeta.json')
    assert Path('eossr-v0.2/codemeta.json').exists()


def test_get_codemeta_from_zipurl():
    codemeta = get_codemeta_from_zipurl(_testurl)
    assert codemeta['name'] == 'eossr'


def test_zip_repository():
    from eossr.utils import zip_repository
    from eossr import ROOT_DIR
    zip_file = zip_repository(ROOT_DIR, 'test_zipping_v0.1.zip')
    assert Path(zip_file).exists()
    with ZipFile(zip_file) as zo:
        for file in zo.namelist():
            assert '.git/' not in file
    Path(zip_file).unlink()

    with tempfile.TemporaryDirectory() as tmpdir:
        subtmpdir = tempfile.mkdtemp(dir=tmpdir)
        _, tmpfile = tempfile.mkstemp(dir=subtmpdir)
        Path(tmpfile).write_text("Hello World")
        zip_filename = Path(subtmpdir).joinpath('test_zip_repo.zip').as_posix()
        zip_repository(tmpdir, zip_filename=zip_filename)
        with ZipFile(zip_filename) as zo:
            assert 'test_zip_repo.zip' not in [Path(f).name for f in zo.namelist()]
            assert os.path.join(os.path.join(os.path.basename(tmpdir), os.path.basename(subtmpdir)),
                                os.path.basename(tmpfile)) in zo.namelist()
