#!/usr/bin/env python

import re
from setuptools import setup, find_packages
from pathlib import Path


entry_points = {'console_scripts': [
    'eossr-zip-repository = eossr.scripts.zip_repository:main',
    'eossr-codemeta2zenodo = eossr.scripts.eossr_codemeta2zenodo:main',
    'eossr-upload-repository = eossr.scripts.eossr_upload_repository:main',
    'eossr-check-connection-zenodo = eossr.scripts.check_connection_zenodo:main',
    ]
}


def get_property(prop, project):
    result = re.search(r'{}\s*=\s*[\'"]([^\'"]*)[\'"]'.format(prop),
                       open(project + '/__init__.py').read())
    return result.group(1)


this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()


setup(
    name='eossr',
    version=get_property('__version__', 'eossr'),
    description="ESCAPE OSSR library",
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=[
        "requests",
        "bs4",
    ],
    packages=find_packages(),
    scripts=['eossr/scripts/gitlab_prepare_upload_zenodo.sh'],
    tests_require=['pytest'],
    author='Thomas Vuillaume & Enrique Garcia',
    author_email='vuillaume@lapp.in2p3.fr',
    url='https://gitlab.in2p3.fr/escape2020/wp3/eossr',
    license='MIT',
    entry_points=entry_points,
    package_data={
        'eossr': ['metadata/schema/.zenodo.json', 'metadata/schema/codemeta.json']
    }
)
